==> volcano-model-v1beta1-6.2.0-sources.jar: io/fabric8/volcano/scheduling/v1beta1/QueueSpecFluentImpl.java <==
package io.fabric8.volcano.scheduling.v1beta1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.Quantity;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class QueueSpecFluentImpl<A extends QueueSpecFluent<A>> extends BaseFluent<A> implements QueueSpecFluent<A>{
  public QueueSpecFluentImpl() {
  }
  public QueueSpecFluentImpl(QueueSpec instance) {
    this.withCapability(instance.getCapability()); 
    this.withReclaimable(instance.getReclaimable()); 
    this.withWeight(instance.getWeight()); 
  }
  private Map<String,Quantity> capability;
  private Boolean reclaimable;
  private Integer weight;
  public A addToCapability(String key,Quantity value) {
    if(this.capability == null && key != null && value != null) { this.capability = new LinkedHashMap(); }
    if(key != null && value != null) {this.capability.put(key, value);} return (A)this;
  }
  public A addToCapability(Map<String,Quantity> map) {
    if(this.capability == null && map != null) { this.capability = new LinkedHashMap(); }
    if(map != null) { this.capability.putAll(map);} return (A)this;
  }
  public A removeFromCapability(String key) {
    if(this.capability == null) { return (A) this; }
    if(key != null && this.capability != null) {this.capability.remove(key);} return (A)this;
  }
  public A removeFromCapability(Map<String,Quantity> map) {
    if(this.capability == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.capability != null){this.capability.remove(key);}}} return (A)this;
  }
  public Map<String,Quantity> getCapability() {
    return this.capability;
  }
  public <K,V>A withCapability(Map<String,Quantity> capability) {
    if (capability == null) { this.capability =  null;} else {this.capability = new LinkedHashMap(capability);} return (A) this;
  }
  public Boolean hasCapability() {
    return this.capability != null;
  }
  public Boolean getReclaimable() {
    return this.reclaimable;
  }
  public A withReclaimable(Boolean reclaimable) {
    this.reclaimable=reclaimable; return (A) this;
  }
  public Boolean hasReclaimable() {
    return this.reclaimable != null;
  }
  public Integer getWeight() {
    return this.weight;
  }
  public A withWeight(Integer weight) {
    this.weight=weight; return (A) this;
  }
  public Boolean hasWeight() {
    return this.weight != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    QueueSpecFluentImpl that = (QueueSpecFluentImpl) o;
    if (capability != null ? !capability.equals(that.capability) :that.capability != null) return false;
    if (reclaimable != null ? !reclaimable.equals(that.reclaimable) :that.reclaimable != null) return false;
    if (weight != null ? !weight.equals(that.weight) :that.weight != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(capability,  reclaimable,  weight,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (capability != null && !capability.isEmpty()) { sb.append("capability:"); sb.append(capability + ","); }
    if (reclaimable != null) { sb.append("reclaimable:"); sb.append(reclaimable + ","); }
    if (weight != null) { sb.append("weight:"); sb.append(weight); }
    sb.append("}");
    return sb.toString();
  }
  public A withReclaimable() {
    return withReclaimable(true);
  }
  
}

==> volcano-model-v1beta1-6.7.2-sources.jar: io/fabric8/volcano/scheduling/v1beta1/QueueSpecFluentImpl.java <==
package io.fabric8.volcano.scheduling.v1beta1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.Quantity;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class QueueSpecFluentImpl<A extends QueueSpecFluent<A>> extends BaseFluent<A> implements QueueSpecFluent<A>{
  public QueueSpecFluentImpl() {
  }
  public QueueSpecFluentImpl(QueueSpec instance) {
    if (instance != null) {
      this.withCapability(instance.getCapability());
      this.withReclaimable(instance.getReclaimable());
      this.withWeight(instance.getWeight());
    }
  }
  private Map<String,Quantity> capability;
  private Boolean reclaimable;
  private Integer weight;
  public A addToCapability(String key,Quantity value) {
    if(this.capability == null && key != null && value != null) { this.capability = new LinkedHashMap(); }
    if(key != null && value != null) {this.capability.put(key, value);} return (A)this;
  }
  public A addToCapability(Map<String,Quantity> map) {
    if(this.capability == null && map != null) { this.capability = new LinkedHashMap(); }
    if(map != null) { this.capability.putAll(map);} return (A)this;
  }
  public A removeFromCapability(String key) {
    if(this.capability == null) { return (A) this; }
    if(key != null && this.capability != null) {this.capability.remove(key);} return (A)this;
  }
  public A removeFromCapability(Map<String,Quantity> map) {
    if(this.capability == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.capability != null){this.capability.remove(key);}}} return (A)this;
  }
  public Map<String,Quantity> getCapability() {
    return this.capability;
  }
  public <K,V>A withCapability(Map<String,Quantity> capability) {
    if (capability == null) { this.capability =  null;} else {this.capability = new LinkedHashMap(capability);} return (A) this;
  }
  public Boolean hasCapability() {
    return this.capability != null;
  }
  public Boolean getReclaimable() {
    return this.reclaimable;
  }
  public A withReclaimable(Boolean reclaimable) {
    this.reclaimable=reclaimable; return (A) this;
  }
  public Boolean hasReclaimable() {
    return this.reclaimable != null;
  }
  public Integer getWeight() {
    return this.weight;
  }
  public A withWeight(Integer weight) {
    this.weight=weight; return (A) this;
  }
  public Boolean hasWeight() {
    return this.weight != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    QueueSpecFluentImpl that = (QueueSpecFluentImpl) o;
    if (!java.util.Objects.equals(capability, that.capability)) return false;

    if (!java.util.Objects.equals(reclaimable, that.reclaimable)) return false;

    if (!java.util.Objects.equals(weight, that.weight)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(capability,  reclaimable,  weight,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (capability != null && !capability.isEmpty()) { sb.append("capability:"); sb.append(capability + ","); }
    if (reclaimable != null) { sb.append("reclaimable:"); sb.append(reclaimable + ","); }
    if (weight != null) { sb.append("weight:"); sb.append(weight); }
    sb.append("}");
    return sb.toString();
  }
  public A withReclaimable() {
    return withReclaimable(true);
  }
  
}
